@@ -111,7 +111,7 @@ _get_table  (hb_tag_t tag, void *user_data)
     return hb_blob_create_empty ();
 
   return hb_blob_create ((const char *) buffer, length,
-			 HB_MEMORY_MODE_WRITEABLE,
+			 HB_MEMORY_MODE_WRITABLE,
 			 g_free, NULL);
 }
 
@@ -149,7 +149,7 @@ pango_ot_info_get (FT_Face face)
 
 	blob = hb_blob_create ((const char *) face->stream->base,
 			       (unsigned int) face->stream->size,
-			       HB_MEMORY_MODE_READONLY_MAY_MAKE_WRITEABLE,
+			       HB_MEMORY_MODE_READONLY_MAY_MAKE_WRITABLE,
 			       NULL, NULL);
 	info->hb_face = hb_face_create_for_data (blob, face->face_index);
 	hb_blob_destroy (blob);
@@ -455,7 +455,7 @@ pango_ot_info_list_scripts (PangoOTInfo      *info,
 {
   hb_tag_t tt = get_hb_table_type (table_type);
   PangoOTTag *result;
-  unsigned int count;
+  unsigned int count = 0;
 
   hb_ot_layout_table_get_script_tags (info->hb_face, tt, &count, NULL);
   result = g_new (PangoOTTag, count + 1);
@@ -485,7 +485,7 @@ pango_ot_info_list_languages (PangoOTInfo      *info,
 {
   hb_tag_t tt = get_hb_table_type (table_type);
   PangoOTTag *result;
-  unsigned int count;
+  unsigned int count = 0;
 
   hb_ot_layout_script_get_language_tags (info->hb_face, tt, script_index, &count, NULL);
   result = g_new (PangoOTTag, count + 1);
@@ -519,7 +519,7 @@ pango_ot_info_list_features  (PangoOTInfo      *info,
 {
   hb_tag_t tt = get_hb_table_type (table_type);
   PangoOTTag *result;
-  unsigned int count;
+  unsigned int count = 0;
 
   hb_ot_layout_language_get_feature_tags (info->hb_face, tt, script_index, language_index, &count, NULL);
   result = g_new (PangoOTTag, count + 1);
@@ -541,7 +541,7 @@ _pango_ot_info_substitute  (const PangoOTInfo    *info,
       PangoOTRule *rule = &g_array_index (ruleset->rules, PangoOTRule, i);
       hb_mask_t mask;
       unsigned int lookup_count, j;
-      unsigned int lookup_indexes[100];
+      unsigned int lookup_indexes[1000];
 
       if (rule->table_type != PANGO_OT_TABLE_GSUB)
 	continue;
@@ -588,7 +588,7 @@ _pango_ot_info_position    (const PangoOTInfo    *info,
       PangoOTRule *rule = &g_array_index (ruleset->rules, PangoOTRule, i);
       hb_mask_t mask;
       unsigned int lookup_count, j;
-      unsigned int lookup_indexes[100];
+      unsigned int lookup_indexes[1000];
 
       if (rule->table_type != PANGO_OT_TABLE_GPOS)
 	continue;
