@@ -73,6 +73,7 @@ _pango_ft2_font_new (PangoFT2FontMap *ft2fontmap,
 
   ft2font = (PangoFT2Font *)g_object_new (PANGO_TYPE_FT2_FONT,
 					  "pattern", pattern,
+					  "fontmap", fontmap,
 					  NULL);
 
   if (FcPatternGetDouble (pattern, FC_PIXEL_SIZE, 0, &d) == FcResultMatch)
@@ -239,7 +240,7 @@ pango_ft2_font_get_face (PangoFont *font)
       if (error != FT_Err_Ok)
 	{
 	bail0:
-	  load_fallback_face (ft2font, filename);
+	  load_fallback_face (ft2font, (char *) filename);
 	}
 
       g_assert (ft2font->face);
@@ -317,14 +318,12 @@ pango_ft2_font_get_glyph_extents (PangoFont      *font,
 				  PangoRectangle *logical_rect)
 {
   PangoFT2GlyphInfo *info;
+  gboolean empty = FALSE;
 
   if (glyph == PANGO_GLYPH_EMPTY)
     {
-      if (ink_rect)
-	ink_rect->x = ink_rect->y = ink_rect->height = ink_rect->width = 0;
-      if (logical_rect)
-	logical_rect->x = logical_rect->y = logical_rect->height = logical_rect->width = 0;
-      return;
+      glyph = pango_fc_font_get_glyph ((PangoFcFont *) font, ' ');
+      empty = TRUE;
     }
 
   if (glyph & PANGO_GLYPH_UNKNOWN_FLAG)
@@ -366,6 +365,15 @@ pango_ft2_font_get_glyph_extents (PangoFont      *font,
     *ink_rect = info->ink_rect;
   if (logical_rect)
     *logical_rect = info->logical_rect;
+
+  if (empty)
+    {
+      if (ink_rect)
+	ink_rect->x = ink_rect->y = ink_rect->height = ink_rect->width = 0;
+      if (logical_rect)
+	logical_rect->x = logical_rect->width = 0;
+      return;
+    }
 }
 
 /**
@@ -420,12 +428,12 @@ pango_ft2_font_real_lock_face (PangoFcFont *font)
 }
 
 static void
-pango_ft2_font_real_unlock_face (PangoFcFont *font)
+pango_ft2_font_real_unlock_face (PangoFcFont *font G_GNUC_UNUSED)
 {
 }
 
 static gboolean
-pango_ft2_free_glyph_info_callback (gpointer key,
+pango_ft2_free_glyph_info_callback (gpointer key G_GNUC_UNUSED,
 				    gpointer value,
 				    gpointer data)
 {
